summaryrefslogtreecommitdiff
path: root/Build/source/texk/detex
diff options
context:
space:
mode:
authorPeter Breitenlohner <peb@mppmu.mpg.de>2012-08-02 09:02:15 +0000
committerPeter Breitenlohner <peb@mppmu.mpg.de>2012-08-02 09:02:15 +0000
commit07bf7b9c954d96cff26691380ae814e33e298cb7 (patch)
tree320f8b1654af04556a96078e4387465a8677da79 /Build/source/texk/detex
parenta50e145e100080813d24a0239e649c11be7b2819 (diff)
detex, dviljk: Rename Foo -> my_Foo to avoid name conflict (from W32TeX)
git-svn-id: svn://tug.org/texlive/trunk@27286 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build/source/texk/detex')
-rw-r--r--Build/source/texk/detex/detex-2.8-PATCHES/ChangeLog5
-rw-r--r--Build/source/texk/detex/detex-2.8-PATCHES/patch-07-rename48
-rw-r--r--Build/source/texk/detex/detex-2.8/detex.h2
-rw-r--r--Build/source/texk/detex/detex-2.8/detex.l8
-rw-r--r--Build/source/texk/detex/detex.c8
5 files changed, 62 insertions, 9 deletions
diff --git a/Build/source/texk/detex/detex-2.8-PATCHES/ChangeLog b/Build/source/texk/detex/detex-2.8-PATCHES/ChangeLog
index 00c9a1dad03..a36f36d7fc7 100644
--- a/Build/source/texk/detex/detex-2.8-PATCHES/ChangeLog
+++ b/Build/source/texk/detex/detex-2.8-PATCHES/ChangeLog
@@ -1,3 +1,8 @@
+2012-08-02 Peter Breitenlohner <peb@mppmu.mpg.de>
+
+ * patch-07-rename: Rename ERROR -> my_ERROR to avoid a conflict
+ with WIN32 headers (from W32TeX).
+
2012-06-21 Peter Breitenlohner <peb@mppmu.mpg.de>
* patch-06-never-interactive (new): Added the never-interactive
diff --git a/Build/source/texk/detex/detex-2.8-PATCHES/patch-07-rename b/Build/source/texk/detex/detex-2.8-PATCHES/patch-07-rename
new file mode 100644
index 00000000000..4f8c1452d2a
--- /dev/null
+++ b/Build/source/texk/detex/detex-2.8-PATCHES/patch-07-rename
@@ -0,0 +1,48 @@
+diff -ur detex-2.8.orig/detex.h detex-2.8/detex.h
+--- detex-2.8.orig/detex.h 2008-02-01 20:55:51.000000000 +0100
++++ detex-2.8/detex.h 2012-08-02 10:31:17.000000000 +0200
+@@ -78,4 +78,4 @@
+ #define CHTEXOPT 't'
+ #define CHWORDOPT 'w'
+
+-#define ERROR -1
++#define my_ERROR -1
+diff -ur detex-2.8.orig/detex.l detex-2.8/detex.l
+--- detex-2.8.orig/detex.l 2012-06-21 11:52:31.000000000 +0200
++++ detex-2.8/detex.l 2012-08-02 10:31:20.000000000 +0200
+@@ -580,7 +580,7 @@
+ sb = SafeMalloc(strlen(sbEnvList) + 1, "malloc for SetEnvIgnore failed");
+ (void) strcpy(sb, sbEnvList);
+ csbEnvIgnore = SeparateList(sb, rgsbEnvIgnore, CHENVSEP, MAXENVS);
+- if (csbEnvIgnore == ERROR)
++ if (csbEnvIgnore == my_ERROR)
+ ErrorExit("The environtment list contains too many environments");
+ }
+
+@@ -738,7 +738,7 @@
+ (void)strcat(sbPaths, DEFAULTINPUTS);
+
+ csbInputPaths = SeparateList(sbPaths, rgsbInputPaths, CHPATHSEP, MAXINPUTPATHS);
+- if (csbInputPaths == ERROR)
++ if (csbInputPaths == my_ERROR)
+ #ifdef OS2
+ ErrorExit("TEXINPUT(S) environment variable has too many paths");
+ #else
+@@ -751,7 +751,7 @@
+ ** SeparateList -- takes a chSep separated list sbList, replaces the
+ ** chSep's with NULLs and sets rgsbList[i] to the beginning of
+ ** the ith word in sbList. The number of words is returned. A
+-** ERROR is returned if there are more than csbMax words.
++** my_ERROR is returned if there are more than csbMax words.
+ ******/
+
+ int
+@@ -764,7 +764,7 @@
+ if ((sbList = index(sbList, chSep)))
+ *sbList++ = '\0';
+ }
+- return(sbList && *sbList ? ERROR : csbList);
++ return(sbList && *sbList ? my_ERROR : csbList);
+ }
+
+ /******
diff --git a/Build/source/texk/detex/detex-2.8/detex.h b/Build/source/texk/detex/detex-2.8/detex.h
index 68aa9b1d064..0b4c71d5099 100644
--- a/Build/source/texk/detex/detex-2.8/detex.h
+++ b/Build/source/texk/detex/detex-2.8/detex.h
@@ -78,4 +78,4 @@
#define CHTEXOPT 't'
#define CHWORDOPT 'w'
-#define ERROR -1
+#define my_ERROR -1
diff --git a/Build/source/texk/detex/detex-2.8/detex.l b/Build/source/texk/detex/detex-2.8/detex.l
index 7b4aaa1a1de..398dbfea632 100644
--- a/Build/source/texk/detex/detex-2.8/detex.l
+++ b/Build/source/texk/detex/detex-2.8/detex.l
@@ -580,7 +580,7 @@ SetEnvIgnore(const char *sbEnvList)
sb = SafeMalloc(strlen(sbEnvList) + 1, "malloc for SetEnvIgnore failed");
(void) strcpy(sb, sbEnvList);
csbEnvIgnore = SeparateList(sb, rgsbEnvIgnore, CHENVSEP, MAXENVS);
- if (csbEnvIgnore == ERROR)
+ if (csbEnvIgnore == my_ERROR)
ErrorExit("The environtment list contains too many environments");
}
@@ -738,7 +738,7 @@ SetInputPaths(void)
(void)strcat(sbPaths, DEFAULTINPUTS);
csbInputPaths = SeparateList(sbPaths, rgsbInputPaths, CHPATHSEP, MAXINPUTPATHS);
- if (csbInputPaths == ERROR)
+ if (csbInputPaths == my_ERROR)
#ifdef OS2
ErrorExit("TEXINPUT(S) environment variable has too many paths");
#else
@@ -751,7 +751,7 @@ SetInputPaths(void)
** SeparateList -- takes a chSep separated list sbList, replaces the
** chSep's with NULLs and sets rgsbList[i] to the beginning of
** the ith word in sbList. The number of words is returned. A
-** ERROR is returned if there are more than csbMax words.
+** my_ERROR is returned if there are more than csbMax words.
******/
int
@@ -764,7 +764,7 @@ SeparateList(char *sbList, char *rgsbList[], char chSep, int csbMax)
if ((sbList = index(sbList, chSep)))
*sbList++ = '\0';
}
- return(sbList && *sbList ? ERROR : csbList);
+ return(sbList && *sbList ? my_ERROR : csbList);
}
/******
diff --git a/Build/source/texk/detex/detex.c b/Build/source/texk/detex/detex.c
index a2e3020acd4..169b4ee018c 100644
--- a/Build/source/texk/detex/detex.c
+++ b/Build/source/texk/detex/detex.c
@@ -3893,7 +3893,7 @@ SetEnvIgnore(const char *sbEnvList)
sb = SafeMalloc(strlen(sbEnvList) + 1, "malloc for SetEnvIgnore failed");
(void) strcpy(sb, sbEnvList);
csbEnvIgnore = SeparateList(sb, rgsbEnvIgnore, CHENVSEP, MAXENVS);
- if (csbEnvIgnore == ERROR)
+ if (csbEnvIgnore == my_ERROR)
ErrorExit("The environtment list contains too many environments");
}
@@ -4051,7 +4051,7 @@ SetInputPaths(void)
(void)strcat(sbPaths, DEFAULTINPUTS);
csbInputPaths = SeparateList(sbPaths, rgsbInputPaths, CHPATHSEP, MAXINPUTPATHS);
- if (csbInputPaths == ERROR)
+ if (csbInputPaths == my_ERROR)
#ifdef OS2
ErrorExit("TEXINPUT(S) environment variable has too many paths");
#else
@@ -4064,7 +4064,7 @@ SetInputPaths(void)
** SeparateList -- takes a chSep separated list sbList, replaces the
** chSep's with NULLs and sets rgsbList[i] to the beginning of
** the ith word in sbList. The number of words is returned. A
** ERROR is returned if there are more than csbMax words.
******/
int
@@ -4077,7 +4077,7 @@ SeparateList(char *sbList, char *rgsbList[], char chSep, int csbMax)
if ((sbList = index(sbList, chSep)))
*sbList++ = '\0';
}
- return(sbList && *sbList ? ERROR : csbList);
+ return(sbList && *sbList ? my_ERROR : csbList);
}
/******
@@ -4064,7 +4064,7 @@ SetInputPaths(void)
** chSep's with NULLs and sets rgsbList[i] to the beginning of
** the ith word in sbList. The number of words is returned. A
-** ERROR is returned if there are more than csbMax words.
+** my_ERROR is returned if there are more than csbMax words.
******/
int